@@ -85,7 +85,7 @@ AG_col_names <- function(variable) {
 #' @export
 #'
 #' @examples
-#' read_AG_counts(
+#' AG_counts <- read_AG_counts(
 #'   system.file(
 #'     "extdata",
 #'     "example1sec.csv",
@@ -93,6 +93,7 @@ AG_col_names <- function(variable) {
 #'   ),
 #'   skip = 11
 #' )
+#' head(AG_counts)
 #'
 read_AG_counts <- function(file, verbose = FALSE, skip = 10,
     nrows = 10, header = FALSE, ...) {
@@ -149,7 +150,9 @@ read_AG_counts <- function(file, verbose = FALSE, skip = 10,
       }
       names(AG) <- variables
       AG <- AG_time(AG, meta)
-      if (verbose) message_update(16, dur = get_duration(timer))
+      if (verbose) message_update(
+        16, dur = PAutilities::get_duration(timer)
+      )
       return(AG)
     }
 
@@ -160,7 +163,7 @@ read_AG_counts <- function(file, verbose = FALSE, skip = 10,
       }
       names(AG) <- mode_vars
       AG <- AG_time(AG, meta)
-      if (verbose) message_update(16, dur = get_duration(timer))
+      if (verbose) message_update(16, dur = PAutilities::get_duration(timer))
       return(AG)
     }
 
@@ -170,7 +173,9 @@ read_AG_counts <- function(file, verbose = FALSE, skip = 10,
       message_update(3)
     }
     AG <- AG_time(AG, meta)
-    if (verbose) message_update(16, dur = get_duration(timer))
+    if (verbose) message_update(
+      16, dur = PAutilities::get_duration(timer)
+    )
     return(AG)
   } else {
     if (verbose) message_update(6)
@@ -193,7 +198,9 @@ read_AG_counts <- function(file, verbose = FALSE, skip = 10,
     }
 
     AG <- AG_time(AG, meta)
-    if (verbose) message_update(16, dur = get_duration(timer))
+    if (verbose) message_update(
+      16, dur = PAutilities::get_duration(timer)
+    )
     return(AG)
   }
 }
@@ -305,15 +312,22 @@ check_inc <- function(AG, verbose = FALSE) {
 
 #' Provide the run time of processing
 #'
-#' @param timer The initial time
+#' @param timer a proc_time object giving the initial time
 #'
 #' @examples
 #' timer <- proc.time()
 #' Sys.sleep(2.2)
-#' AGread:::message_update(16, dur = get_duration(timer))
+#' \donttest{
+#'   # Gives warning about deprecation
+#'   # get_duration(timer)
 #'
-#' @export
+#'   # Instead use
+#'   PAutilities::get_duration(timer)
+#' }
 #'
-get_duration <- function(timer) {
-  format((proc.time() - timer)[3] / 60, digits = 1, nsmall = 1)
-}
+#'
+#' @name get_duration-deprecated
+#' @usage get_duration(timer)
+#' @seealso \code{\link{AGread-deprecated}}
+#' @keywords internal
+NULL
